@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009, 2010, 2012, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -34,7 +34,7 @@ _p_linux = sys.platform.startswith('linux')
 
 if not _p_linux:
     raise NotImplementedError(
-        'the %r platform is not supported' % sys.platform
+        'the {sys.platform!r} platform is not supported'.format(sys=sys)
     )
 
 if _p_linux:
@@ -67,7 +67,7 @@ if _p_linux:
         mute=0x07,
         misc=0x08,
         mail=0x09,
-        charging=0x0a,
+        charging=0x0A,
     )
 
     _EVENT_DEV_MIN = 0x0D40
@@ -146,10 +146,10 @@ class LedKit(object):
         return [led for led in self._leds.values() if led.get()]
 
     def __repr__(self):
-        return '%s.%s(%r)' % (
-            self.__class__.__module__,
-            self.__class__.__name__,
-            self._filename
+        return '{mod}.{cls}({file!r})'.format(
+            mod=type(self).__module__,
+            cls=type(self).__name__,
+            file=self._filename,
         )
 
 
@@ -183,7 +183,7 @@ class Led(object):
         return c._get() & self._n != 0
 
     def __repr__(self):
-        return '%s.%s' % (self._control, self._name)
+        return '{ctrl}.{name}'.format(ctrl=self._control, name=self._name)
 
 if _p_linux:
 
@@ -210,4 +210,4 @@ if _p_linux:
         def get(self):
             raise NotImplementedError
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
